const API_BASE_URL = '/api';

export interface Match {
  id: string;
  name: string;
  date: string;
  location: string;
  totalSeats: number;
  availableSeats: number;
  price: number;
  pdfFiles: string[];
  timeoutMinutes: number;
  timeoutDate: string;
}

export interface Ticket {
  id: string;
  matchId: string;
  seatNumber: number;
  customerName: string;
  customerEmail: string;
  customerPhone: string;
  status: 'pending' | 'confirmed' | 'expired';
  createdAt: string;
}

export interface BookingFormData {
  name: string;
  email: string;
  phone: string;
  seatNumber: number;
}

async function handleResponse<T>(response: Response): Promise<T> {
  if (!response.ok) {
    const error = await response.json().catch(() => ({ message: 'An error occurred' }));
    throw new Error(error.message || 'An error occurred');
  }
  return response.json();
}

export const api = {
  matches: {
    getAll: async (): Promise<Match[]> => {
      const response = await fetch(`${API_BASE_URL}/matches`);
      return handleResponse<Match[]>(response);
    },
    getById: async (id: string): Promise<Match> => {
      const response = await fetch(`${API_BASE_URL}/matches/${id}`);
      return handleResponse<Match>(response);
    }
  },
  tickets: {
    create: async (matchId: string, data: BookingFormData): Promise<Ticket> => {
      const response = await fetch(`${API_BASE_URL}/tickets`, {
        method: 'POST',
        headers: {
          'Content-Type': 'application/json',
        },
        body: JSON.stringify({ matchId, ...data }),
      });
      return handleResponse<Ticket>(response);
    },
    getStatus: async (id: string): Promise<Ticket> => {
      const response = await fetch(`${API_BASE_URL}/tickets/${id}/status`);
      return handleResponse<Ticket>(response);
    }
  }
};
